# dose_response

[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/samcphee/HTS_doseresponse/blob/main/HTS_IC50_fitting.ipynb)

Package for bulk processing of dose-response data in tabular format.

See the Medium Article [High-Throughput Dose-Response Data Analysis](https://medium.com/@sahmcphee/high-throughput-dose-response-data-analysis-47d27d2bf545) for usage example.

## Version

0.0.1 Initial commit 

0.0.2 minor updates 

0.0.3 minor updates 

0.0.4 minor updates 

0.0.5 update readme (Current Release)


